#[non_exhaustive]pub struct Peripherals {Show 112 fields
pub GPIO0: GPIO0<'static>,
pub GPIO1: GPIO1<'static>,
pub GPIO2: GPIO2<'static>,
pub GPIO3: GPIO3<'static>,
pub GPIO4: GPIO4<'static>,
pub GPIO5: GPIO5<'static>,
pub GPIO6: GPIO6<'static>,
pub GPIO7: GPIO7<'static>,
pub GPIO8: GPIO8<'static>,
pub GPIO9: GPIO9<'static>,
pub GPIO10: GPIO10<'static>,
pub GPIO11: GPIO11<'static>,
pub GPIO12: GPIO12<'static>,
pub GPIO13: GPIO13<'static>,
pub GPIO14: GPIO14<'static>,
pub GPIO15: GPIO15<'static>,
pub GPIO16: GPIO16<'static>,
pub GPIO17: GPIO17<'static>,
pub GPIO18: GPIO18<'static>,
pub GPIO19: GPIO19<'static>,
pub GPIO20: GPIO20<'static>,
pub GPIO21: GPIO21<'static>,
pub GPIO26: GPIO26<'static>,
pub GPIO27: GPIO27<'static>,
pub GPIO28: GPIO28<'static>,
pub GPIO29: GPIO29<'static>,
pub GPIO30: GPIO30<'static>,
pub GPIO31: GPIO31<'static>,
pub GPIO32: GPIO32<'static>,
pub GPIO33: GPIO33<'static>,
pub GPIO34: GPIO34<'static>,
pub GPIO35: GPIO35<'static>,
pub GPIO36: GPIO36<'static>,
pub GPIO37: GPIO37<'static>,
pub GPIO38: GPIO38<'static>,
pub GPIO39: GPIO39<'static>,
pub GPIO40: GPIO40<'static>,
pub GPIO41: GPIO41<'static>,
pub GPIO42: GPIO42<'static>,
pub GPIO43: GPIO43<'static>,
pub GPIO44: GPIO44<'static>,
pub GPIO45: GPIO45<'static>,
pub GPIO46: GPIO46<'static>,
pub DMA_SPI2: DMA_SPI2<'static>,
pub DMA_SPI3: DMA_SPI3<'static>,
pub DMA_I2S0: DMA_I2S0<'static>,
pub DMA_CRYPTO: DMA_CRYPTO<'static>,
pub DMA_COPY: DMA_COPY<'static>,
pub SDM_CH0: SDM_CH0<'static>,
pub SDM_CH1: SDM_CH1<'static>,
pub SDM_CH2: SDM_CH2<'static>,
pub SDM_CH3: SDM_CH3<'static>,
pub SDM_CH4: SDM_CH4<'static>,
pub SDM_CH5: SDM_CH5<'static>,
pub SDM_CH6: SDM_CH6<'static>,
pub SDM_CH7: SDM_CH7<'static>,
pub AES: AES<'static>,
pub APB_SARADC: APB_SARADC<'static>,
pub DS: DS<'static>,
pub EXTMEM: EXTMEM<'static>,
pub FE: FE<'static>,
pub FE2: FE2<'static>,
pub GPIO: GPIO<'static>,
pub GPIO_SD: GPIO_SD<'static>,
pub HMAC: HMAC<'static>,
pub I2C_ANA_MST: I2C_ANA_MST<'static>,
pub I2C0: I2C0<'static>,
pub I2C1: I2C1<'static>,
pub I2S0: I2S0<'static>,
pub INTERRUPT_CORE0: INTERRUPT_CORE0<'static>,
pub IO_MUX: IO_MUX<'static>,
pub LEDC: LEDC<'static>,
pub NRX: NRX<'static>,
pub PCNT: PCNT<'static>,
pub PMS: PMS<'static>,
pub RMT: RMT<'static>,
pub RNG: RNG<'static>,
pub RSA: RSA<'static>,
pub LPWR: LPWR<'static>,
pub RTC_TIMER: RTC_TIMER<'static>,
pub LP_I2C0: LP_I2C0<'static>,
pub RTC_IO: RTC_IO<'static>,
pub SENS: SENS<'static>,
pub SHA: SHA<'static>,
pub SPI0: SPI0<'static>,
pub SPI1: SPI1<'static>,
pub SPI2: SPI2<'static>,
pub SPI3: SPI3<'static>,
pub SYSCON: SYSCON<'static>,
pub SYSTEM: SYSTEM<'static>,
pub SYSTIMER: SYSTIMER<'static>,
pub TIMG0: TIMG0<'static>,
pub TIMG1: TIMG1<'static>,
pub TWAI0: TWAI0<'static>,
pub UART0: UART0<'static>,
pub UART1: UART1<'static>,
pub UHCI0: UHCI0<'static>,
pub USB_FS: USB_FS<'static>,
pub XTS_AES: XTS_AES<'static>,
pub WIFI: WIFI<'static>,
pub ADC1: ADC1<'static>,
pub ADC2: ADC2<'static>,
pub DAC1: DAC1<'static>,
pub DAC2: DAC2<'static>,
pub FLASH: FLASH<'static>,
pub GPIO_DEDICATED: GPIO_DEDICATED<'static>,
pub PSRAM: PSRAM<'static>,
pub ULP_RISCV_CORE: ULP_RISCV_CORE<'static>,
pub FROM_CPU_INTR0: FROM_CPU_INTR0<'static>,
pub FROM_CPU_INTR1: FROM_CPU_INTR1<'static>,
pub FROM_CPU_INTR2: FROM_CPU_INTR2<'static>,
pub FROM_CPU_INTR3: FROM_CPU_INTR3<'static>,
}Expand description
The Peripherals struct provides access to all of the hardware peripherals on the chip.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.GPIO0: GPIO0<'static>The GPIO0 peripheral.
GPIO1: GPIO1<'static>The GPIO1 peripheral.
GPIO2: GPIO2<'static>The GPIO2 peripheral.
GPIO3: GPIO3<'static>The GPIO3 peripheral.
GPIO4: GPIO4<'static>The GPIO4 peripheral.
GPIO5: GPIO5<'static>The GPIO5 peripheral.
GPIO6: GPIO6<'static>The GPIO6 peripheral.
GPIO7: GPIO7<'static>The GPIO7 peripheral.
GPIO8: GPIO8<'static>The GPIO8 peripheral.
GPIO9: GPIO9<'static>The GPIO9 peripheral.
GPIO10: GPIO10<'static>The GPIO10 peripheral.
GPIO11: GPIO11<'static>The GPIO11 peripheral.
GPIO12: GPIO12<'static>The GPIO12 peripheral.
GPIO13: GPIO13<'static>The GPIO13 peripheral.
GPIO14: GPIO14<'static>The GPIO14 peripheral.
GPIO15: GPIO15<'static>The GPIO15 peripheral.
GPIO16: GPIO16<'static>The GPIO16 peripheral.
GPIO17: GPIO17<'static>The GPIO17 peripheral.
GPIO18: GPIO18<'static>The GPIO18 peripheral.
GPIO19: GPIO19<'static>The GPIO19 peripheral.
GPIO20: GPIO20<'static>The GPIO20 peripheral.
GPIO21: GPIO21<'static>The GPIO21 peripheral.
GPIO26: GPIO26<'static>The GPIO26 peripheral.
GPIO27: GPIO27<'static>The GPIO27 peripheral.
GPIO28: GPIO28<'static>The GPIO28 peripheral.
GPIO29: GPIO29<'static>The GPIO29 peripheral.
GPIO30: GPIO30<'static>The GPIO30 peripheral.
GPIO31: GPIO31<'static>The GPIO31 peripheral.
GPIO32: GPIO32<'static>The GPIO32 peripheral.
GPIO33: GPIO33<'static>The GPIO33 peripheral.
GPIO34: GPIO34<'static>The GPIO34 peripheral.
GPIO35: GPIO35<'static>The GPIO35 peripheral.
GPIO36: GPIO36<'static>The GPIO36 peripheral.
GPIO37: GPIO37<'static>The GPIO37 peripheral.
GPIO38: GPIO38<'static>The GPIO38 peripheral.
GPIO39: GPIO39<'static>The GPIO39 peripheral.
GPIO40: GPIO40<'static>The GPIO40 peripheral.
GPIO41: GPIO41<'static>The GPIO41 peripheral.
GPIO42: GPIO42<'static>The GPIO42 peripheral.
GPIO43: GPIO43<'static>The GPIO43 peripheral.
GPIO44: GPIO44<'static>The GPIO44 peripheral.
GPIO45: GPIO45<'static>The GPIO45 peripheral.
GPIO46: GPIO46<'static>The GPIO46 peripheral.
DMA_SPI2: DMA_SPI2<'static>unstable only.The DMA_SPI2 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DMA_SPI3: DMA_SPI3<'static>unstable only.The DMA_SPI3 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DMA_I2S0: DMA_I2S0<'static>unstable only.The DMA_I2S0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DMA_CRYPTO: DMA_CRYPTO<'static>unstable only.The DMA_CRYPTO peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DMA_COPY: DMA_COPY<'static>unstable only.The DMA_COPY peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH0: SDM_CH0<'static>unstable only.The SDM_CH0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH1: SDM_CH1<'static>unstable only.The SDM_CH1 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH2: SDM_CH2<'static>unstable only.The SDM_CH2 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH3: SDM_CH3<'static>unstable only.The SDM_CH3 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH4: SDM_CH4<'static>unstable only.The SDM_CH4 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH5: SDM_CH5<'static>unstable only.The SDM_CH5 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH6: SDM_CH6<'static>unstable only.The SDM_CH6 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SDM_CH7: SDM_CH7<'static>unstable only.The SDM_CH7 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
AES: AES<'static>unstable only.The AES peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
APB_SARADC: APB_SARADC<'static>unstable only.The APB_SARADC peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DS: DS<'static>unstable only.The DS peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
EXTMEM: EXTMEM<'static>unstable only.The EXTMEM peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FE: FE<'static>unstable only.The FE peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FE2: FE2<'static>unstable only.The FE2 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
GPIO: GPIO<'static>unstable only.The GPIO peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
GPIO_SD: GPIO_SD<'static>unstable only.The GPIO_SD peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
HMAC: HMAC<'static>unstable only.The HMAC peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
I2C_ANA_MST: I2C_ANA_MST<'static>unstable only.The I2C_ANA_MST peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
I2C0: I2C0<'static>The I2C0 peripheral.
I2C1: I2C1<'static>The I2C1 peripheral.
I2S0: I2S0<'static>unstable only.The I2S0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
INTERRUPT_CORE0: INTERRUPT_CORE0<'static>unstable only.The INTERRUPT_CORE0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
IO_MUX: IO_MUX<'static>unstable only.The IO_MUX peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
LEDC: LEDC<'static>unstable only.The LEDC peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
NRX: NRX<'static>unstable only.The NRX peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
PCNT: PCNT<'static>unstable only.The PCNT peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
PMS: PMS<'static>unstable only.The PMS peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
RMT: RMT<'static>unstable only.The RMT peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
RNG: RNG<'static>unstable only.The RNG peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
RSA: RSA<'static>unstable only.The RSA peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
LPWR: LPWR<'static>unstable only.The LPWR peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
RTC_TIMER: RTC_TIMER<'static>unstable only.The RTC_TIMER peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
LP_I2C0: LP_I2C0<'static>unstable only.The LP_I2C0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
RTC_IO: RTC_IO<'static>unstable only.The RTC_IO peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SENS: SENS<'static>unstable only.The SENS peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SHA: SHA<'static>unstable only.The SHA peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SPI0: SPI0<'static>unstable only.The SPI0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SPI1: SPI1<'static>unstable only.The SPI1 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SPI2: SPI2<'static>The SPI2 peripheral.
SPI3: SPI3<'static>The SPI3 peripheral.
SYSCON: SYSCON<'static>unstable only.The SYSCON peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SYSTEM: SYSTEM<'static>unstable only.The SYSTEM peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
SYSTIMER: SYSTIMER<'static>unstable only.The SYSTIMER peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
TIMG0: TIMG0<'static>unstable only.The TIMG0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
TIMG1: TIMG1<'static>unstable only.The TIMG1 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
TWAI0: TWAI0<'static>unstable only.The TWAI0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
UART0: UART0<'static>The UART0 peripheral.
UART1: UART1<'static>The UART1 peripheral.
UHCI0: UHCI0<'static>unstable only.The UHCI0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
USB_FS: USB_FS<'static>unstable only.The USB_FS peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
XTS_AES: XTS_AES<'static>unstable only.The XTS_AES peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
WIFI: WIFI<'static>The WIFI peripheral.
ADC1: ADC1<'static>unstable only.The ADC1 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
ADC2: ADC2<'static>unstable only.The ADC2 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DAC1: DAC1<'static>unstable only.The DAC1 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
DAC2: DAC2<'static>unstable only.The DAC2 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FLASH: FLASH<'static>unstable only.The FLASH peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
GPIO_DEDICATED: GPIO_DEDICATED<'static>unstable only.The GPIO_DEDICATED peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
PSRAM: PSRAM<'static>unstable only.The PSRAM peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
ULP_RISCV_CORE: ULP_RISCV_CORE<'static>unstable only.The ULP_RISCV_CORE peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FROM_CPU_INTR0: FROM_CPU_INTR0<'static>unstable only.The FROM_CPU_INTR0 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FROM_CPU_INTR1: FROM_CPU_INTR1<'static>unstable only.The FROM_CPU_INTR1 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FROM_CPU_INTR2: FROM_CPU_INTR2<'static>unstable only.The FROM_CPU_INTR2 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
FROM_CPU_INTR3: FROM_CPU_INTR3<'static>unstable only.The FROM_CPU_INTR3 peripheral.
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.